<?php

if (!function_exists ('filtre_slugify_dist')) {
	/**
	 * FIXME le core de SPIP 4.0 fournit identifiant_slug
	 *
	 * Copie de spip_bonux v3.5.4
	 *
	 * Cette fonction permet de transformer un texte clair en nom court pouvant servir d'identifiant, class, id, url...
	 * en ne conservant que des caracteres alphanumeriques et un separateur
	 *
	 * @param string $texte
	 *   Texte à transformer en nom machine
	 * @param string $type
	 *
	 * @param array $options
	 *   string separateur : par défaut, un underscore `_`.
	 *   int longueur_maxi : par defaut 60
	 *
	 * @return string
	 */
	function filtre_slugify_dist ($texte, $type = '', $options = array()) {

		$separateur = (isset($options['separateur']) ? $options['separateur'] : '_');
		$longueur_maxi = (isset($options['longueur_maxi']) ? $options['longueur_maxi'] : 60);

		if (!function_exists ('translitteration')) {
			include_spip ('inc/charsets');
		}

		// pas de balise html
		if (strpos ($texte, '<') !== false) {
			$texte = strip_tags ($texte);
		}
		if (strpos ($texte, '&') !== false) {
			$texte = unicode2charset ($texte);
		}
		// On enlève les espaces indésirables
		$texte = trim ($texte);

		// On enlève les accents et cie
		$texte = translitteration ($texte);

		// On remplace tout ce qui n'est pas un mot par un separateur
		$texte = preg_replace (',\W+,ms', $separateur, $texte);

		// nettoyer les doubles occurences du separateur si besoin
		while (strpos ($texte, "$separateur$separateur") !== false) {
			$texte = str_replace ("$separateur$separateur", $separateur, $texte);
		}

		// pas de separateur au debut ni a la fin
		$texte = trim ($texte, $separateur);

		// en minuscules
		$texte = strtolower ($texte);

		switch ($type) {
			case 'class':
			case 'id':
			case 'anchor':
				if (preg_match (',^\d,', $texte)) {
					$texte = substr ($type, 0, 1) . $texte;
				}
		}

		if (strlen ($texte) > $longueur_maxi) {
			$texte = substr ($texte, 0, $longueur_maxi);
		}

		return $texte;
	}
}

if (!function_exists('slugify')) {
	function slugify($texte, $type = '', $options = array()) {
		$slugify = chercher_filtre('slugify');
		return $slugify($texte, $type, $options);
	}
}


// copie un peu modifiée de la fonction définie dans public/cacher.php
if (!function_exists('gunzip_page')) {
	function gunzip_page(&$page) {
		if (isset ($page['gz']) and $page['gz']) {
			$page['texte'] = gzuncompress($page['texte']);
			$page['gz'] = false; // ne pas gzuncompress deux fois une meme page
		}
	}
}
else
	die("La fonction gunzip_page ne devrait pas être déjà définie"); // à défaut de disposer de la lib nobug

if (!function_exists('plugin_est_actif')) {
	function plugin_est_actif($prefixe) {
		$f = chercher_filtre('info_plugin');
		return $f($prefixe, 'est_actif');
	}
}

if (!function_exists('cache_est_sessionne')) {
	function cache_est_sessionne ($nomcache) {
		if (preg_match (XRAY_PATTERN_SESSION_AUTH, $nomcache))
			return 'session_auth';
		elseif (preg_match (XRAY_PATTERN_SESSION_ANON, $nomcache))
			return 'session_anon';
		else
			return false;
	}

	function cache_est_talon ($nomcache, &$data='') {
		if (preg_match(XRAY_PATTERN_SESSION, $nomcache))
			return false;
		if (!is_array($data)) // textwheels par exemple
			return null;
		return !isset($data['contexte']);
	}

	function cache_est_dynamique ($nomcache, &$data='') {
		if (!is_array($data) or !isset($data['process_ins'])) // textwheels par exemple
			return null;
		return $data['process_ins'] == 'php';
	}

	function cache_est_statique ($nomcache, &$data='') {
		if (!is_array($data) or !isset($data['process_ins'])) // textwheels par exemple
			return null;
		return $data['process_ins'] == 'html';
	}

	function cache_est_page ($nomcache, &$data='') {
		if (!is_array($data)) // textwheels par exemple
			return null;
		// On délègue à une fonction à définir pour chaque site car ça dépend du format des urls
		if (function_exists('xray_reconnaitre_si_cache_est_page')) {
			return xray_reconnaitre_si_cache_est_page($nomcache, $data);
		}
		// Par défaut on utilise une heuristique qui couvre pas mal de cas :
		// les pages spip.php et les urls raccourcies /1234
		return
			(stripos (strrev($nomcache), strrev('/spip')) === 0)
			or preg_match("~/\d+$~", $nomcache);
	}

/* Exemple : définition adaptée pour les urls historiques en "article.php?id_article="
function xray_reconnaitre_si_cache_est_page ($nomcache, $data) {
	$len = strlen($nomcache);
	foreach (['/spip', 'article/article', 'rubrique/rubrique'] as $pattern) {
		$pos = strrpos ($nomcache, $pattern);
		$minpos = $len - strlen ($pattern) -1; // parfois il y a un _ en plus à la fin
		if (($pos !== false) and ($pos >= $minpos)) {
			return true;
		}
	}
	return false;
	}
*/

	function cache_est_perime ($nomcache, &$data='') {
		global $meta_derniere_modif;
		if ($data['creation_time'] + $data['ttl'] <= time ()) {
			if ($data['creation_time'] <  $meta_derniere_modif) {
				return 'PÉRIMÉ / APCu et SPIP';
			}
			return 'PÉRIMÉ / APCu';
		}
		if ($data['creation_time'] <  $meta_derniere_modif) {
			return 'PÉRIMÉ / SPIP';
		}
		return false;
	}
}
